@@ -19,42 +19,26 @@
 
 """Deploy CLI module."""
 
-import os
 import shutil
 from pathlib import Path
-from typing import List, Optional, cast
+from typing import Optional, cast
 
 import click
 from aea.cli.registry.settings import REGISTRY_REMOTE
 from aea.cli.utils.click_utils import password_option, registry_flag
 from aea.cli.utils.context import Context
-from aea.configurations.constants import SKILL
-from aea.configurations.data_types import PublicId
-from aea.helpers.base import cd
-from aea.helpers.io import open_file
-from aea.helpers.yaml_utils import yaml_dump_all, yaml_load_all
-from compose.cli import main as docker_compose
 
-from autonomy.cli.fetch import fetch_service
-from autonomy.cli.utils.click_utils import chain_selection_flag
-from autonomy.configurations.constants import DEFAULT_SERVICE_CONFIG_FILE
-from autonomy.configurations.loader import load_service_config
-from autonomy.constants import DEFAULT_BUILD_FOLDER, DEFAULT_KEYS_FILE
-from autonomy.deploy.build import generate_deployment
-from autonomy.deploy.chain import ServiceRegistry
-from autonomy.deploy.constants import (
-    AGENT_KEYS_DIR,
-    BENCHMARKS_DIR,
-    INFO,
-    LOGGING_LEVELS,
-    LOG_DIR,
-    PERSISTENT_DATA_DIR,
-    TM_STATE_DIR,
-    VENVS_DIR,
+from autonomy.cli.helpers.deployment import (
+    build_and_deploy_from_token,
+    build_deployment,
+    run_deployment,
 )
+from autonomy.cli.utils.click_utils import chain_selection_flag
+from autonomy.constants import DEFAULT_BUILD_FOLDER, DEFAULT_KEYS_FILE
+from autonomy.deploy.base import NotValidKeysFile
+from autonomy.deploy.constants import INFO, LOGGING_LEVELS
 from autonomy.deploy.generators.docker_compose.base import DockerComposeGenerator
 from autonomy.deploy.generators.kubernetes.base import KubernetesGenerator
-from autonomy.deploy.image import build_image
 
 
 PACKAGES_DIR = "packages_dir"
@@ -175,8 +159,10 @@ def build_deployment_command(  # pylint: disable=too-many-arguments, too-many-lo
     """Build deployment setup for n agents."""
 
     keys_file = Path(keys_file or DEFAULT_KEYS_FILE).absolute()
-    build_dir = Path(output_dir or DEFAULT_BUILD_FOLDER).absolute()
+    if not keys_file.exists():
+        raise click.ClickException("Please provide valid path for keys file.")
 
+    build_dir = Path(output_dir or DEFAULT_BUILD_FOLDER).absolute()
     packages_dir = Path(packages_dir or Path.cwd() / "packages").absolute()
     open_aea_dir = Path(open_aea_dir or Path.home() / "open-aea").absolute()
     open_autonomy_dir = Path(
@@ -200,23 +186,23 @@ def build_deployment_command(  # pylint: disable=too-many-arguments, too-many-lo
 
     try:
         build_deployment(
-            keys_file,
-            build_dir,
-            deployment_type,
-            dev_mode,
-            force_overwrite,
-            number_of_agents,
-            password,
-            packages_dir,
-            open_aea_dir,
-            open_autonomy_dir,
+            keys_file=keys_file,
+            build_dir=build_dir,
+            deployment_type=deployment_type,
+            dev_mode=dev_mode,
+            force_overwrite=force_overwrite,
+            number_of_agents=number_of_agents,
+            password=password,
+            packages_dir=packages_dir,
+            open_aea_dir=open_aea_dir,
+            open_autonomy_dir=open_autonomy_dir,
             log_level=log_level,
             substitute_env_vars=aev,
             image_version=image_version,
             use_hardhat=use_hardhat,
             use_acn=use_acn,
         )
-    except Exception as e:  # pylint: disable=broad-except
+    except (NotValidKeysFile, FileNotFoundError, FileExistsError) as e:
         shutil.rmtree(build_dir)
         raise click.ClickException(str(e)) from e
 
@@ -241,6 +227,12 @@ def build_deployment_command(  # pylint: disable=too-many-arguments, too-many-lo
 def run(build_dir: Path, no_recreate: bool, remove_orphans: bool) -> None:
     """Run deployment."""
     build_dir = Path(build_dir or Path.cwd()).absolute()
+
+    if not (build_dir / DockerComposeGenerator.output_name).exists():
+        raise click.ClickException(
+            f"Deployment configuration does not exist @ {build_dir}"
+        )
+
     run_deployment(build_dir, no_recreate, remove_orphans)
 
 
@@ -280,160 +272,21 @@ def run_deployment_from_token(  # pylint: disable=too-many-arguments, too-many-l
     ctx = cast(Context, click_context.obj)
     ctx.registry_type = REGISTRY_REMOTE
     keys_file = Path(keys_file or DEFAULT_KEYS_FILE).absolute()
-    service_registry = ServiceRegistry(chain_type, rpc_url, service_contract_address)
 
-    click.echo(f"Building service deployment using token ID: {token_id}")
-    metadata = service_registry.resolve_token_id(token_id)
-    _, agent_instances = service_registry.get_agent_instances(token_id)
-    click.echo("Service name: " + metadata["name"])
-
-    _, multisig_address, *_ = service_registry.get_service_info(token_id)
-    *_, service_hash = metadata["code_uri"].split("//")
-    public_id = PublicId(author="valory", name="service", package_hash=service_hash)
-    service_path = fetch_service(ctx, public_id)
-    build_dir = service_path / DEFAULT_BUILD_FOLDER
-
-    update_multisig_address(service_path, multisig_address)
-    service = load_service_config(service_path, substitute_env_vars=aev)
-
-    with cd(service_path):
-        if not skip_image:
-            click.echo("Building required images.")
-            build_image(agent=service.agent)
-
-        build_deployment(
-            keys_file,
-            build_dir=build_dir,
-            deployment_type=DockerComposeGenerator.deployment_type,
-            dev_mode=False,
-            force_overwrite=True,
-            number_of_agents=n,
-            agent_instances=agent_instances,
-            substitute_env_vars=aev,
+    try:
+        build_and_deploy_from_token(
+            token_id=token_id,
+            keys_file=keys_file,
+            chain_type=chain_type,
+            rpc_url=rpc_url,
+            service_contract_address=service_contract_address,
+            skip_image=skip_image,
+            n=n,
+            aev=aev,
         )
-
-    click.echo("Service build successful.")
-    run_deployment(build_dir)
-
-
-# TODO: extract into appropriate utils with validations
-def update_multisig_address(service_path: Path, address: str) -> None:
-    """Update the multisig address on the service config."""
-
-    with open_file(service_path / DEFAULT_SERVICE_CONFIG_FILE) as fp:
-        config, *overrides = yaml_load_all(
-            fp,
-        )
-
-    for override in overrides:
-        if override["type"] == SKILL:
-            override["setup_args"]["args"]["setup"]["safe_contract_address"] = [
-                address,
-            ]
-
-    with open_file(service_path / DEFAULT_SERVICE_CONFIG_FILE, mode="w+") as fp:
-        yaml_dump_all([config, *overrides], fp)
-
-
-def build_deployment(  # pylint: disable=too-many-arguments, too-many-locals
-    keys_file: Path,
-    build_dir: Path,
-    deployment_type: str,
-    dev_mode: bool,
-    force_overwrite: bool,
-    number_of_agents: Optional[int] = None,
-    password: Optional[str] = None,
-    packages_dir: Optional[Path] = None,
-    open_aea_dir: Optional[Path] = None,
-    open_autonomy_dir: Optional[Path] = None,
-    agent_instances: Optional[List[str]] = None,
-    log_level: str = INFO,
-    substitute_env_vars: bool = False,
-    image_version: Optional[str] = None,
-    use_hardhat: bool = False,
-    use_acn: bool = False,
-) -> None:
-    """Build deployment."""
-    if build_dir.is_dir():
-        if not force_overwrite:
-            raise click.ClickException(f"Build already exists @ {build_dir}")
-        shutil.rmtree(build_dir)
-
-    click.echo(f"Building deployment @ {build_dir}")
-    build_dir.mkdir()
-    _build_dirs(build_dir)
-
-    report = generate_deployment(
-        service_path=Path.cwd(),
-        type_of_deployment=deployment_type,
-        private_keys_file_path=keys_file,
-        private_keys_password=password,
-        number_of_agents=number_of_agents,
-        build_dir=build_dir,
-        dev_mode=dev_mode,
-        packages_dir=packages_dir,
-        open_aea_dir=open_aea_dir,
-        open_autonomy_dir=open_autonomy_dir,
-        agent_instances=agent_instances,
-        log_level=log_level,
-        substitute_env_vars=substitute_env_vars,
-        image_version=image_version,
-        use_hardhat=use_hardhat,
-        use_acn=use_acn,
-    )
-    click.echo(report)
-
-
-def _build_dirs(build_dir: Path) -> None:
-    """Build necessary directories."""
-
-    for dir_path in [
-        (PERSISTENT_DATA_DIR,),
-        (PERSISTENT_DATA_DIR, LOG_DIR),
-        (PERSISTENT_DATA_DIR, TM_STATE_DIR),
-        (PERSISTENT_DATA_DIR, BENCHMARKS_DIR),
-        (PERSISTENT_DATA_DIR, VENVS_DIR),
-        (AGENT_KEYS_DIR,),
-    ]:
-        path = Path(build_dir, *dir_path)
-        path.mkdir()
-        # TOFIX for macOS
-        try:
-            os.chown(path, 1000, 1000)
-        except PermissionError:
-            click.echo(
-                f"Updating permissions failed for {path}, please do it manually."
-            )
-
-
-def run_deployment(
-    build_dir: Path, no_recreate: bool = False, remove_orphans: bool = False
-) -> None:
-    """Run deployment."""
-
-    click.echo(f"Running build @ {build_dir}")
-    project = docker_compose.project_from_options(build_dir, {})
-    commands = docker_compose.TopLevelCommand(project=project)
-    commands.up(
-        {
-            "--detach": False,
-            "--no-color": False,
-            "--quiet-pull": False,
-            "--no-deps": False,
-            "--force-recreate": not no_recreate,
-            "--always-recreate-deps": False,
-            "--no-recreate": no_recreate,
-            "--no-build": False,
-            "--no-start": False,
-            "--build": True,
-            "--abort-on-container-exit": False,
-            "--attach-dependencies": False,
-            "--timeout": None,
-            "--renew-anon-volumes": False,
-            "--remove-orphans": remove_orphans,
-            "--exit-code-from": None,
-            "--scale": [],
-            "--no-log-prefix": False,
-            "SERVICE": None,
-        }
-    )
+    except (
+        NotValidKeysFile,
+        FileNotFoundError,
+        FileExistsError,
+    ) as e:
+        raise click.ClickException(str(e)) from e
