@@ -287,7 +287,7 @@ class IntegrationBaseCase(FSMBehaviourBaseCase):
         return tuple(incoming_messages)
 
 
-class _HarHatHelperIntegration(IntegrationBaseCase):
+class HardHatHelperIntegration(IntegrationBaseCase):
     """Base test class for integration tests with HardHat provider."""
 
     hardhat_provider: BaseProvider
