@@ -66,7 +66,7 @@ class TestBuildImage(BaseCliTest):
 
         result = self.run_cli()
 
-        assert result.exit_code == 0, f"{result.stdout_bytes}\n{result.stderr_bytes}"
+        assert result.exit_code == 0, result.output
         assert (
             len(self.docker_api.images(name=f"valory/oar-hello_world:{self.hash_}"))
             == 1
@@ -79,7 +79,7 @@ class TestBuildImage(BaseCliTest):
 
         result = self.run_cli(("--dev",))
 
-        assert result.exit_code == 0, f"{result.stdout_bytes}\n{result.stderr_bytes}"
+        assert result.exit_code == 0, result.output
         assert len(self.docker_api.images(name="valory/oar-hello_world:dev")) == 1
 
     def test_build_version(
@@ -90,8 +90,27 @@ class TestBuildImage(BaseCliTest):
         test_version = "".join(choices(ascii_letters, k=6))
         result = self.run_cli(("--version", test_version))
 
-        assert result.exit_code == 0, f"{result.stdout_bytes}\n{result.stderr_bytes}"
+        assert result.exit_code == 0, result.output
         assert (
             len(self.docker_api.images(name=f"valory/oar-hello_world:{test_version}"))
             == 1
         )
+
+
+class TestBuildImageFailures(BaseCliTest):
+    """Test build image command."""
+
+    cli_options: Tuple[str, ...] = ("build-image",)
+    docker_api: docker.APIClient
+    build_dir: Path
+    hash_: str
+
+    def test_service_file_missing(
+        self,
+    ) -> None:
+        """Test prod build."""
+
+        result = self.run_cli()
+
+        assert result.exit_code == 1, result.output
+        assert "Service configuration not found the current directory" in result.output
